@@ -1,11 +1,15 @@
 package App::CharmKit::Command::lint;
-$App::CharmKit::Command::lint::VERSION = '2.05';
+$App::CharmKit::Command::lint::VERSION = '2.06';
 
 use strict;
 use warnings;
+no warnings 'experimental::signatures';
+use feature 'signatures';
 use App::CharmKit -command;
 use parent 'App::CharmKit::Role::Lint';
 
+sub abstract { "charm linter" }
+sub description { "Lints your charm and its hooks" }
 sub opt_spec {
     return ();
 }
