@@ -1,5 +1,5 @@
 package App::CharmKit::HookUtil;
-$App::CharmKit::HookUtil::VERSION = '2.05';
+$App::CharmKit::HookUtil::VERSION = '2.06';
 # ABSTRACT: Additional helper hook routines
 
 use strict;
@@ -7,10 +7,10 @@ use warnings;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 use Rex::Commands::Run;
-
+use FindBin;
 use base "Exporter::Tiny";
 
-our @EXPORT = qw(config resource unit status);
+our @EXPORT = qw(config resource unit status plugin);
 
 
 sub config($key) {
@@ -33,6 +33,14 @@ sub status ($level = "active", $msg = "Ready") {
     return run "status-set $level $msg";
 }
 
+
+sub plugin($name, $opts={}) {
+    my $name_path = "$FindBin::Bin/../lib/$name.pm";
+    require $name_path;
+    return "$name"->new($opts);
+}
+
+
 1;
 
 __END__
@@ -66,6 +74,10 @@ running charm
 
 Sets the charm's current status of execution
 
+=item plugin($name, %opts)
+
+Load a plugin, optionally passing options
+
 =back
 
 =head1 AUTHOR
