@@ -1,5 +1,5 @@
 package charm;
-$charm::VERSION = '2.05';
+$charm::VERSION = '2.06';
 # ABSTRACT: Sugary Juju charm authoring goodness
 
 
@@ -9,6 +9,9 @@ use warnings;
 no bareword::filehandles;
 no indirect ':fatal';
 
+use autobox                       ();
+use autobox::Core                 ();
+use true                          ();
 use feature                       ();
 use Path::Tiny                    ();
 use Test::More                    ();
@@ -45,10 +48,13 @@ sub import {
     'strict'->import::into($target);
     'warnings'->import::into($target);
     'English'->import::into($target, '-no_match_vars');
+    'autobox'->import::into($target);
+    'autobox::Core'->import::into($target);
 
     warnings->unimport('once');
     warnings->unimport('experimental');
     warnings->unimport('experimental::signatures');
+    warnings->unimport('reserved');
 
     bareword::filehandles->unimport;
     indirect->unimport(':fatal');
@@ -56,6 +62,8 @@ sub import {
     feature->import(':5.20');
     feature->import('signatures');
 
+    true->import;
+
     POSIX->import::into($target, qw(strftime));
     Rex->import::into($target, '-feature' => [qw(no_path_cleanup)]);
     Rex::Commands->import::into($target);
